from edison_dictionary_api import EdisonBaseAPI


class approversController(EdisonBaseAPI):
    """Approver - is someone who can approve edited by editors data in the database."""

    _controller_name = "approversController"

    def assignAll(self, editorsAssignment):
        """Full assignment to approver.

        Args:
            editorsAssignment: (string): editorsAssignment

        Returns:
            application/json;charset=UTF-8
        """

        api_parameters = ['editorsAssignment']
        parameters_names_map = {}
        api = '/approvers/assignAll'
        actions = ['post']
        params = self._format_params_for_api(locals(), api_parameters, parameters_names_map)
        return self._process_api(self._controller_name, api, actions, params)

    def assignCountry(self, approverId, dictionaryId, **kwargs):
        """Assign or unassign country to approver.

        Args:
            approverId: (string): approverId
            assign: (boolean): assign
            dictionaryId: (string): dictionaryId

        Returns:
            application/json;charset=UTF-8
        """

        api_parameters = ['approverId', 'dictionaryId', '**kwargs']
        parameters_names_map = {}
        api = '/approvers/assignCountry'
        actions = ['post']
        params = self._format_params_for_api(locals(), api_parameters, parameters_names_map)
        return self._process_api(self._controller_name, api, actions, params)

    def assignEditor(self, approverId, editorId, **kwargs):
        """Assign or disable assignation editor to approver.

        Args:
            approverId: (string): approverId
            assign: (boolean): assign
            editorId: (string): editorId

        Returns:
            application/json;charset=UTF-8
        """

        api_parameters = ['approverId', 'editorId', '**kwargs']
        parameters_names_map = {}
        api = '/approvers/assignEditor'
        actions = ['post']
        params = self._format_params_for_api(locals(), api_parameters, parameters_names_map)
        return self._process_api(self._controller_name, api, actions, params)

    def assignTopic(self, approverId, dictionaryId, **kwargs):
        """Assign or unassign topic to approver.

        Args:
            approverId: (string): approverId
            assign: (boolean): assign
            dictionaryId: (string): dictionaryId

        Returns:
            application/json;charset=UTF-8
        """

        api_parameters = ['approverId', 'dictionaryId', '**kwargs']
        parameters_names_map = {}
        api = '/approvers/assignTopic'
        actions = ['post']
        params = self._format_params_for_api(locals(), api_parameters, parameters_names_map)
        return self._process_api(self._controller_name, api, actions, params)

    def countriesList(self, **kwargs):
        """Returns the list of countries for approver.

        Args:
            approverId: (string): approverId

        Returns:
            application/json;charset=UTF-8
        """

        api_parameters = ['**kwargs']
        parameters_names_map = {}
        api = '/approvers/countriesList'
        actions = ['post']
        params = self._format_params_for_api(locals(), api_parameters, parameters_names_map)
        return self._process_api(self._controller_name, api, actions, params)

    def editorsList(self, **kwargs):
        """Returns the list of editors for approver.

        Args:
            approverId: (string): approverId

        Returns:
            application/json;charset=UTF-8
        """

        api_parameters = ['**kwargs']
        parameters_names_map = {}
        api = '/approvers/editorsList'
        actions = ['post']
        params = self._format_params_for_api(locals(), api_parameters, parameters_names_map)
        return self._process_api(self._controller_name, api, actions, params)

    def list(self):
        """Return the list of approvers."""

        api_parameters = None
        parameters_names_map = {}
        api = '/approvers/list'
        actions = ['post']
        params = self._format_params_for_api(locals(), api_parameters, parameters_names_map)
        return self._process_api(self._controller_name, api, actions, params)

    def listAll(self, approverId):
        """Return the lists of approver's stuff.

        Args:
            approverId: (string): approverId

        Returns:
            application/json;charset=UTF-8
        """

        api_parameters = ['approverId']
        parameters_names_map = {}
        api = '/approvers/listAll'
        actions = ['post']
        params = self._format_params_for_api(locals(), api_parameters, parameters_names_map)
        return self._process_api(self._controller_name, api, actions, params)

    def topicsList(self, **kwargs):
        """Returns the list of topics for approver.

        Args:
            approverId: (string): approverId

        Returns:
            application/json;charset=UTF-8
        """

        api_parameters = ['**kwargs']
        parameters_names_map = {}
        api = '/approvers/topicsList'
        actions = ['post']
        params = self._format_params_for_api(locals(), api_parameters, parameters_names_map)
        return self._process_api(self._controller_name, api, actions, params)
