from edison_dictionary_api import EdisonBaseAPI


class databasesController(EdisonBaseAPI):
    """Databases."""

    _controller_name = "databasesController"

    def backup(self, **kwargs):
        """Start backup.

        Args:
            incremental: (boolean): incremental
            removeFolder: (boolean): removeFolder
            zip: (boolean): zip

        Returns:
            application/json;charset=UTF-8
        """

        api_parameters = ['**kwargs']
        parameters_names_map = {}
        api = '/databases/backup'
        actions = ['post']
        params = self._format_params_for_api(locals(), api_parameters, parameters_names_map)
        return self._process_api(self._controller_name, api, actions, params)

    def doctypeArchive(self, doctypeLanguageId):
        """Create archive file for doctype documents.

        Args:
            doctypeLanguageId: (string): doctypeLanguageId

        Returns:
            application/json;charset=UTF-8
        """

        api_parameters = ['doctypeLanguageId']
        parameters_names_map = {}
        api = '/databases/doctypeArchive'
        actions = ['post']
        params = self._format_params_for_api(locals(), api_parameters, parameters_names_map)
        return self._process_api(self._controller_name, api, actions, params)

    def downloadDoctypeDocuments(self, doctypeLanguageId):
        """Download doctype documents archive.

        Args:
            doctypeLanguageId: (string): doctypeLanguageId

        Returns:
            application/json;charset=UTF-8
        """

        api_parameters = ['doctypeLanguageId']
        parameters_names_map = {}
        api = '/databases/downloadDoctypeDocuments'
        actions = ['post']
        params = self._format_params_for_api(locals(), api_parameters, parameters_names_map)
        return self._process_api(self._controller_name, api, actions, params)

    def downloadEmotionDocuments(self, emotionLanguageId):
        """Download emotion documents archive.

        Args:
            emotionLanguageId: (string): emotionLanguageId

        Returns:
            application/json;charset=UTF-8
        """

        api_parameters = ['emotionLanguageId']
        parameters_names_map = {}
        api = '/databases/downloadEmotionDocuments'
        actions = ['post']
        params = self._format_params_for_api(locals(), api_parameters, parameters_names_map)
        return self._process_api(self._controller_name, api, actions, params)

    def downloadThemeDocuments(self, themeLanguageId):
        """Download theme documents archive.

        Args:
            themeLanguageId: (string): themeLanguageId

        Returns:
            application/json;charset=UTF-8
        """

        api_parameters = ['themeLanguageId']
        parameters_names_map = {}
        api = '/databases/downloadThemeDocuments'
        actions = ['post']
        params = self._format_params_for_api(locals(), api_parameters, parameters_names_map)
        return self._process_api(self._controller_name, api, actions, params)

    def emotionArchive(self, emotionLanguageId):
        """Create archive file for emotion documents.

        Args:
            emotionLanguageId: (string): emotionLanguageId

        Returns:
            application/json;charset=UTF-8
        """

        api_parameters = ['emotionLanguageId']
        parameters_names_map = {}
        api = '/databases/emotionArchive'
        actions = ['post']
        params = self._format_params_for_api(locals(), api_parameters, parameters_names_map)
        return self._process_api(self._controller_name, api, actions, params)

    def themeArchive(self, themeLanguageId):
        """Create archive file for theme documents.

        Args:
            themeLanguageId: (string): themeLanguageId

        Returns:
            application/json;charset=UTF-8
        """

        api_parameters = ['themeLanguageId']
        parameters_names_map = {}
        api = '/databases/themeArchive'
        actions = ['post']
        params = self._format_params_for_api(locals(), api_parameters, parameters_names_map)
        return self._process_api(self._controller_name, api, actions, params)

    def updateBinaries(self):
        """Update binaries."""

        api_parameters = None
        parameters_names_map = {}
        api = '/databases/updateBinaries'
        actions = ['post']
        params = self._format_params_for_api(locals(), api_parameters, parameters_names_map)
        return self._process_api(self._controller_name, api, actions, params)

    def updateDoc2vec(self, **kwargs):
        """Update Doc2vec.

        Args:
            retrainModel: (boolean): retrainModel

        Returns:
            application/json;charset=UTF-8
        """

        api_parameters = ['**kwargs']
        parameters_names_map = {}
        api = '/databases/updateDoc2vec'
        actions = ['post']
        params = self._format_params_for_api(locals(), api_parameters, parameters_names_map)
        return self._process_api(self._controller_name, api, actions, params)

    def updateDoctypes(self):
        """Update Doctypes."""

        api_parameters = None
        parameters_names_map = {}
        api = '/databases/updateDoctypes'
        actions = ['post']
        params = self._format_params_for_api(locals(), api_parameters, parameters_names_map)
        return self._process_api(self._controller_name, api, actions, params)

    def updateEmotions(self):
        """Update emotions."""

        api_parameters = None
        parameters_names_map = {}
        api = '/databases/updateEmotions'
        actions = ['post']
        params = self._format_params_for_api(locals(), api_parameters, parameters_names_map)
        return self._process_api(self._controller_name, api, actions, params)

    def updateIdfModel(self):
        """Update IDF model."""

        api_parameters = None
        parameters_names_map = {}
        api = '/databases/updateIdfModel'
        actions = ['post']
        params = self._format_params_for_api(locals(), api_parameters, parameters_names_map)
        return self._process_api(self._controller_name, api, actions, params)

    def updateSentiment(self):
        """Update sentiment."""

        api_parameters = None
        parameters_names_map = {}
        api = '/databases/updateSentiment'
        actions = ['post']
        params = self._format_params_for_api(locals(), api_parameters, parameters_names_map)
        return self._process_api(self._controller_name, api, actions, params)

    def updateThemes(self):
        """Update themes."""

        api_parameters = None
        parameters_names_map = {}
        api = '/databases/updateThemes'
        actions = ['post']
        params = self._format_params_for_api(locals(), api_parameters, parameters_names_map)
        return self._process_api(self._controller_name, api, actions, params)

    def updateWord2vec(self, **kwargs):
        """Update Word2vec.

        Args:
            retrainModel: (boolean): retrainModel

        Returns:
            application/json;charset=UTF-8
        """

        api_parameters = ['**kwargs']
        parameters_names_map = {}
        api = '/databases/updateWord2vec'
        actions = ['post']
        params = self._format_params_for_api(locals(), api_parameters, parameters_names_map)
        return self._process_api(self._controller_name, api, actions, params)
