from edison_dictionary_api import EdisonBaseAPI


class testDocumentsController(EdisonBaseAPI):
    """Test documents"""

    _controller_name = "testDocumentsController"

    def add(self, testGroupLanguageId, text):
        """Add new test document.

        Args:
            testGroupLanguageId: (string): testGroupLanguageId
            text: (string): text

        Returns:
            application/json;charset=UTF-8
        """

        api_parameters = ['testGroupLanguageId', 'text']
        parameters_names_map = {}
        api = '/test-documents/add'
        actions = ['post']
        params = self._format_params_for_api(locals(), api_parameters, parameters_names_map)
        return self._process_api(self._controller_name, api, actions, params)

    def addFile(self, files, testGroupLanguageId):
        """Add new test document.

        Args:
            files: (array): files
            testGroupLanguageId: (string): testGroupLanguageId

        Returns:
            application/json;charset=UTF-8
        """

        api_parameters = ['files', 'testGroupLanguageId']
        parameters_names_map = {}
        api = '/test-documents/addFile'
        actions = ['post']
        params = self._format_params_for_api(locals(), api_parameters, parameters_names_map)
        return self._process_api(self._controller_name, api, actions, params)

    def edit(self, desiredResult, testDocumentId):
        """Edit existing test document.

        Args:
            desiredResult: (type): desiredResult
            testDocumentId: (string): testDocumentId

        Returns:
            application/json;charset=UTF-8
        """

        api_parameters = ['desiredResult', 'testDocumentId']
        parameters_names_map = {}
        api = '/test-documents/edit'
        actions = ['post']
        params = self._format_params_for_api(locals(), api_parameters, parameters_names_map)
        return self._process_api(self._controller_name, api, actions, params)

    def list(self, testGroupLanguageId, **kwargs):
        """Return list of documents from this test language.

        Args:
            maxNumber: (integer): maxNumber
            offset: (integer): offset
            testGroupLanguageId: (string): testGroupLanguageId

        Returns:
            application/json;charset=UTF-8
        """

        api_parameters = ['testGroupLanguageId', '**kwargs']
        parameters_names_map = {}
        api = '/test-documents/list'
        actions = ['post']
        params = self._format_params_for_api(locals(), api_parameters, parameters_names_map)
        return self._process_api(self._controller_name, api, actions, params)

    def remove(self, testDocumentId):
        """Remove existing test document.

        Args:
            testDocumentId: (string): testDocumentId

        Returns:
            application/json;charset=UTF-8
        """

        api_parameters = ['testDocumentId']
        parameters_names_map = {}
        api = '/test-documents/remove'
        actions = ['post']
        params = self._format_params_for_api(locals(), api_parameters, parameters_names_map)
        return self._process_api(self._controller_name, api, actions, params)

    def retrieve(self, testDocumentId):
        """Retrieve existing test document.

        Args:
            testDocumentId: (string): testDocumentId

        Returns:
            application/json;charset=UTF-8
        """

        api_parameters = ['testDocumentId']
        parameters_names_map = {}
        api = '/test-documents/retrieve'
        actions = ['post']
        params = self._format_params_for_api(locals(), api_parameters, parameters_names_map)
        return self._process_api(self._controller_name, api, actions, params)
